#include "mt.h"

void info(void);
void statistics_menu(void);
void heartbeat(void);
void do_check_for_mail(dtime_t time);
void store_statistics(proginfo *cur, dtime_t now);
